autowisp.database.data_model.condition module — AutoWISP documentation

# autowisp.database.data_model.condition module

## Class Inheritance Diagram

Define the Conditions table for the pipeline

class autowisp.database.data_model.condition.Condition(**kwargs)

  Bases: `DataModelBase`

  The table describing the Conditions for given configuration to apply.

  Each condition is a combination of condition expressions that must all be satisfied simultaneously for the condition to be considered satisfied.

  expression
  expression_id

    The id of the condition expression that is part of this condition.

  id

    A unique identifier for each row.

  notes

    Any user supplied notes describing the condition.

  timestamp

    When record was last changed